@@ -8,7 +8,7 @@ use strict;
 use Spreadsheet::ParseExcel::Utility qw(ExcelFmt);
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
-$VERSION = '0.03'; # 
+$VERSION = '0.04'; # 
 
 my %hFmtDefault = (
     0x00 => '@',
@@ -86,7 +86,8 @@ sub FmtStringDef($$$;$) {
 sub FmtString($$$) {
     my($oThis, $oCell, $oBook) =@_;
 
-    my $sFmtStr = $oThis->FmtStringDef($oCell->{Format}->{FmtIdx}, $oBook);
+    my $sFmtStr = $oThis->FmtStringDef(
+        $oBook->{Format}[$oCell->{FormatNo}]->{FmtIdx}, $oBook);
 
     unless($sFmtStr) {
         if ($oCell->{Type} eq 'Numeric') {
@@ -120,7 +121,8 @@ sub ValFmt($$$) {
     my($Dt, $iFmtIdx, $iNumeric, $Flg1904);
 
     if ($oCell->{Type} eq 'Text') {
-        $Dt = $oThis->TextFmt($oCell->{Val}, $oCell->{Code});
+        $Dt = ((defined $oCell->{Val}) && ($oCell->{Val}))? 
+            $oThis->TextFmt($oCell->{Val}, $oCell->{Code}):''; 
     }
     else {      
         $Dt = $oCell->{Val};
